# myWebKraken
PRoyecto prueba que se conecta a Kraken,  descarga precios de kripro activos y los uestra en web

PAra instalar:
```
pip install -r requirements.txt
```

Para ejecutar

```
No lo se todavia
```